#
# spec file for package python-djvulibre
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-djvulibre
Version:        0.8.5
Release:        bp153.1.21
Summary:        Python Support for the DjVu Image Format
License:        GPL-2.0-only
Group:          Development/Libraries/Python
URL:            http://jwilk.net/software/python-djvulibre
Source0:        https://files.pythonhosted.org/packages/source/p/python-djvulibre/%{name}-%{version}.tar.gz
Source1:        https://files.pythonhosted.org/packages/source/p/python-djvulibre/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  %{python_module Cython >= 0.19}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  djvulibre
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(ddjvuapi) >= 3.5.21
Requires:       djvulibre >= 3.5.21

%python_subpackages

%description
python-djvulibre is a set of Python bindings for the DjVuLibre library,
an open source implementation of DjVu.

%package -n %{name}-doc
Summary:        Python Support for the DjVu Image Format (Documentation)
Group:          Documentation/HTML
BuildArch:      noarch

%description -n %{name}-doc
python-djvulibre is a set of Python bindings for the DjVuLibre library,
an open source implementation of DjVu.

This package contains technical documentation.

%prep
%setup -q
chmod -x examples/*

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build
%python_build build_sphinx

%install
%python_install
rm build/sphinx/html/.buildinfo build/sphinx/html/objects.inv
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
cd tests/
PYTHONPATH=%{buildroot}%{$python_sitearch}
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python -m nose --exclude='^test_export_ps$' --verbose

%files %{python_files}
%license doc/COPYING
%doc doc/changelog doc/credits doc/todo
%{python_sitearch}/*

%files -n %{name}-doc
%doc build/sphinx/html/ examples/

%changelog
* Mon Nov  4 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.8.5.
  * Improve the setup script:
    + Use the current Python interpreter for running Cython.
    + Improve error handling.
* Sun Sep 15 2019 John Vandenberg <jayvdb@gmail.com>
- Fix setup.py to use sys.executable
* Tue Apr  9 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.8.4.
  * Fix compatibility with Python 3.8.
  * Fix error handling when getting S-expressions for outlines,
    annotations or page texts.
* Thu Dec  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
- Do not explicitly state required devel version for python, useless here
* Wed Oct 17 2018 lazy.kent@opensuse.org
- Update to 0.8.2.
  * Explicitly set Cython's Python language level to 2 in pxd files
    too. This might fix build failures with future versions of Cython.
  * Improve documentation:
    + Update the credits file to make it clear that the project is
    no longer being funded.
    + Remove .txt extensions from misc. files.
  * Improve the test suite:
    + Treat the “POSIX” locale the same way as the “C” locale.
    + Add test for version consistency.
    + Add check against BSD make. (Only GNU make is supported.)
* Tue Jun  5 2018 lazy.kent@opensuse.org
- Update to 0.8.1.
  * Improve documentation:
    + Add README, and move information about build requirements there.
    + Apply minor wording and typographic fixes to API documentation.
    + Don't include Sphinx version in HTML documentation.
    + Don't include copyright information in HTML documentation.
  * Improve examples:
    + Make djvu-dump-text and djvu-crop-text compatible with Python 3.
    + Make djvu2png render all layers by default.
    + Unify command-line argument parsing.
  * Explicitly set Cython's Python language level to 2.
    This might fix build failures with future versions of Cython.
  * Improve the build system:
    + Declare build-dependencies (as per PEP-518).
    + Add the bdist_wheel command.
    + Use distutils644 to normalize tarball permissions etc.
    + Fix Python version check.
  * Improve the test suite.
    + Be more tolerant about ps2ascii output.
    Fixes some failures with Ghostscript 9.22.
- Enable run tests (excluding failed).
* Mon Apr  9 2018 lazy.kent@opensuse.org
- Convert to singlespec.
- Disable run tests because of a Ghostscript bug.
- Move examples to the -doc subpackage.
* Thu Aug 11 2016 lazy.kent@opensuse.org
- Update to 0.8.
  * Improve documentation:
    + Fix doctests' compatibility with Python 3.6.
    + Don't require TeX distribution to render math formulas.
    + Simplify some module docstrings.
    + Fix typos in docstrings.
    + Update bug tracker URLs. The project repo has moved to
    GitHub.
  * Improve the setup script:
    + Check Cython version.
    + Use “python -m cython” instead of the “cython” script.
    + Report build-time requirements to pip.
    + Don't use setuptools, except on Windows.
    + Remove poorly standardized “platforms” metadata key. (The
    information about supported platform is available in the
    “Operating System” classifiers.).
    + Add the “Programming Language :: Cython” classifier.
  * Don't hardcode the Python interpreter path in script shebangs;
    use “#!/usr/bin/env python” instead.
* Fri May 20 2016 lazy.kent@opensuse.org
- Update to 0.7.2.
  * Fix compatibility with Cython 0.24.
  * Fix typo in the documentation.
- Correct the source URL.
* Sat Mar 12 2016 lazy.kent@opensuse.org
- Update to 0.7.1.
  * Update URL for “actual and proposed changes to the DjVu
    format”.
  * Use HTTPS for sourceforge.net URLs.
  * Fix a few typos in the documentation.
  * Improve the test suite:
    + Normalize whitespace in ps2ascii output.
* Mon Aug 31 2015 lazy.kent@opensuse.org
- Update to 0.7.
  * Make Expression.from_string() accept both Unicode and byte
    strings.
  * Implement __unicode__() for expressions.
  * Implement __float__() for integer expressions.
  * Be more liberal about object types that can be passed to
    escape_unicode.
  * Fix the long(<intexpr>) return type with Cython 0.23 and Python
  * 2.6.
  * Improve setup.py:
    + Put files that vary with Python version (*.c, config.pxi)
    into a version-specific temporary directory. With this change,
    it's possible to build against multiple Python versions in
    parallel.
  * Update BibTeX URL in the documentation.
  * Improve the test suite.
* Sat Aug 15 2015 lazy.kent@opensuse.org
- Update to 0.6.1.
  * Fix the DjVuLibre version check.
  * Add “const” to variable declarations and function prototypes.
  * Optimize S-expression input/output.
  * Require Cython >= 0.19, or Cython >= 0.20 for Python 3.
    + Remove work-arounds for older versions.
  * Don't pass -Wno-uninitialized to the compiler (modern versions
    of Cython don't generate code that would trigger this warning).
  * Require pkg-config for building on POSIX systems.
- Changes in 0.6.
  * Fix build failure with Cython 0.23.
  * Document which software if required to build the package.
  * Require DjVuLibre >= 3.5.21:
    + Add version check to the setup script.
    + Remove work-arounds for older versions.
    + Remove documentation warnings about older versions.
  * Remove the DjVuLibreBug class.
  * Improve the test suite.
- Changes in 0.5.
  * Make print_into() raise exceptions properly instead of just
    printing them on stderr.
  * Make it possible to print S-expressions into file-like objects
    created by codecs.open().
  * Make djvu.sexpr.__version__ a byte string in Python 2.X.
  * Don't include DjVu file format version in
    djvu.decode.__version__. This information is more conveniently
    available in djvu.decode.DDJVU_VERSION.
  * Make S-expression input/output methods reentrant (DjVuLibre >=
    3.5.26 is required for this feature).
  * Improve error handling.
  * Improve the test suite.
- Changes in 0.4.1.
  * Exclude djvu/config.pxi from the source tarball.
- Changes in 0.4.
  * Drop support for Python 2.5.
  * Add the lvalue attribute to expressions.
  * Use the lvalue in __repr__().
  * Make Symbol objects comparable using “<” and other inequality
    operators.
  * Make it possible to disable octal-escaping of non-ASCII Unicode
    characters when printing expressions into a file.
  * Stop using sphinx.ext.intersphinx.
  * Make djvu.decode.__version__ a byte string in Python 2.X.
  * Improve the test suite.
* Sun Nov 16 2014 lazy.kent@opensuse.org
- Add runtime dependency: djvulibre.
* Thu Nov 13 2014 lazy.kent@opensuse.org
- Update to 0.3.10.
  * Improve error handling in examples.
  * Improve the test suite:
    + When running external programs, don't reset environment
    completely, but only set LC_ALL=C.
    + Skip more tests (instead of making them fail) when they are
    run in an unsuitable environment.
    + Correctly detect ASCII locale encoding on FreeBSD (and
    possibly other non-GNU systems).
    + Don't hard-code libc error messages.
    + Fix test_bad_io failures with Cython ≥ 0.21.
  * Improve setup.py:
    + Make it possible to build the package natively on Windows.
  * Use HTTPS URLs when they are available, in documentation and
    code.
- Run tests. BuildRequires: djvulibre, python-nose.
- Add the source GPG signature and a keyring.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Apr 23 2012 lazy.kent@opensuse.org
- Corrected license: GPL-2.0 only (bnc#758438).
* Tue Mar 20 2012 lazy.kent@opensuse.org
- Update to 0.3.9.
  * Ensure that all S-expression output is 7-bit.
    This is work-around for deb#664626.
* Mon Mar 19 2012 lazy.kent@opensuse.org
- Update to 0.3.8.
  * Ensure that S-expression input/output functions are always
    initialized.
    This is work-around for deb#664442.
* Wed Mar 14 2012 lazy.kent@opensuse.org
- Update to 0.3.7.
  * Use floor division operator instead of relying on "classic"
    division semantics.
* Mon Mar 12 2012 cfarrell@suse.com
- license update: GPL-2.0+
  No indication of GPL-2.0 (i.e. only) licenses in the package
* Tue Mar  6 2012 lazy.kent@opensuse.org
- Update to 0.3.6.
  * Fix compatibility with Python 2.5 (broken since 0.3.0).
* Sun Feb 19 2012 lazy.kent@opensuse.org
- Update to 0.3.5.
  * Compilation improvement.
- Remove executable bit from examples.
* Sat Oct 22 2011 lazy.kent@opensuse.org
- Update to 0.3.4.
  * Fix compatibility with Python 3.X (broken in 0.3.3).
  * Update various external documentation URLs.
- Build requires python-distribute instead of python-setuptools.
- Build doc package. Build requires python-sphinx, graphviz and
  graphviz-gnome.
* Fri Sep  9 2011 lazy.kent@opensuse.org
- Fixed build dependencies (cython -> Cython).
- Corrected License tag.
- Use full URL as a source.
* Wed Apr 13 2011 lazy.kent@opensuse.org
- Update to 0.3.3.
  * Fix test suite compatibility with Python 3.
* Sat Nov 20 2010 lazy.kent.suse@gmail.com
- Update to 0.3.1.
  * Fix encoding issues with djvu.decode.ErrorMessage.
* Fri Oct 29 2010 lazy.kent.suse@gmail.com
- Update to 0.3.0.
  * Add support for Python 3.
- BuildRequires python-setuptools.
* Sat Jun 26 2010 lazy.kent.suse@gmail.com
- Update to 0.1.18.
  * Fix handling of non-ASCII metadata.
* Tue Apr  6 2010 lazy.kent.suse@gmail.com
- Initial package created - 0.1.17.
